import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Cloud Integration for EC2. This allows EC2 cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const extId = new wavefront.CloudIntegrationAwsExternalId("ext_id", {});
 * const ec2 = new wavefront.CloudIntegrationEc2("ec2", {
 *     name: "Test Integration",
 *     roleArn: "arn:aws::1234567:role/example-arn",
 *     externalId: extId.id,
 * });
 * ```
 *
 * ## Import
 *
 * EC2 Cloud Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationEc2:CloudIntegrationEc2 ec2 a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationEc2 extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationEc2 resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationEc2State, opts?: pulumi.CustomResourceOptions): CloudIntegrationEc2;
    /**
     * Returns true if the given object is an instance of CloudIntegrationEc2.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationEc2;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    readonly externalId: pulumi.Output<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * A list of AWS instance tags to use as the `source` name
     * in a series. Default is `["hostname", "host", "name"]`. If no tag in the list is found, the series source
     * is set to the instance id.
     */
    readonly hostnameTags: pulumi.Output<string[] | undefined>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * Create a CloudIntegrationEc2 resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationEc2Args, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationEc2 resources.
 */
export interface CloudIntegrationEc2State {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    externalId?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A list of AWS instance tags to use as the `source` name
     * in a series. Default is `["hostname", "host", "name"]`. If no tag in the list is found, the series source
     * is set to the instance id.
     */
    hostnameTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a CloudIntegrationEc2 resource.
 */
export interface CloudIntegrationEc2Args {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    externalId: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A list of AWS instance tags to use as the `source` name
     * in a series. Default is `["hostname", "host", "name"]`. If no tag in the list is found, the series source
     * is set to the instance id.
     */
    hostnameTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
